-- Engine sound replacements! For you more clever character creators :)

-- To use this in your wad, import it and rename it as LUA_NAME (where NAME is whatever 4 letter name you decide on)

-- While you don't need to follow this formula exactly, the normal engine sounds in kart change as you build speed.
-- As such, they are made in a way that they get slightly higher pitched as your speed increases. With class A as
-- an example... sfx_krta00 is the lowest pitch (and also the sound you here while still), while sfx_krta12 is
-- the highest pitch (and will be heard once you reach top speed)

-- By Namolos (Or you can call me Nathan, idgaf)
-- If you use this, credit isn't required but greatly appreciated

-- Don't touch these :)
local origSounds = {}
local replSounds = {}

local A = sfx_krta00
local B = sfx_krtb00
local C = sfx_krtc00
local D = sfx_krtd00
local E = sfx_krte00
local F = sfx_krtf00
local G = sfx_krtg00
local H = sfx_krth00
local I = sfx_krti00

local allClasses = {{A,B,C},
					{D,E,F},
					{G,H,I}}


--================================--
--     STUFF YOU SHOULD MODIFY    --
--================================--

-- Add your custom engine sounds inside the freeslot call, separated by commas. You can name them whatever you like,
-- but be sure to order them correctly in the call!
--
-- You probably know this, but the name corresponds to whatever you named the sound inside your wad, so...
--   Ex: DSKREX00 = sfx_krex00
--
--   Ex: freeslot("sfx_krex00", "sfx_krex01", ..., sfx_krex12)

freeslot("sfx_npen00",
         "sfx_npen01",
         "sfx_npen02",
         "sfx_npen03",
         "sfx_npen04",
         "sfx_npen05",
         "sfx_npen06",
         "sfx_npen07",
         "sfx_npen08",
         "sfx_npen09",
         "sfx_npen10",
         "sfx_npen11",
         "sfx_npen12")

-- This value must be set to the first sound you slotted in the freeslot() above, so following the example...
--   Ex: REPLACEMENTSOUNDS = sfx_krex00
local REPLACEMENTSOUNDS = sfx_npen00

-- Set the skinname of your character here
local SKINNAME = "nyanpyo"

--================================--
-- END OF STUFF YOU SHOULD MODIFY --
--================================--


--These bits handle all the sound replacement. If you ordered your sounds correctly, all of this should work just fine :)
for i = 0, 12 do
    replSounds[i] = REPLACEMENTSOUNDS+i
end


local function replaceSoundByMobj(m, s, r)
    if (S_SoundPlaying(m, s))
        S_StopSoundByID(m, s)
        S_StartSound(m, r)
    end
end

local function clamp(num, minimum, maximum)
	return min(maximum, max(num, minimum))
end

addHook("MobjThinker", function(mo)
	if not mo then return end
	if not (mo.skin == SKINNAME) then return end
	if not mo.engineClass then
		local speedVar = (mo.player.kartspeed / 3) + ((mo.player.kartspeed % 3) and 1 or 0)
		speedVar = clamp($, 1, 3)
		
		local weightVar = (mo.player.kartweight / 3) + ((mo.player.kartweight % 3) and 1 or 0)
		weightVar = clamp($, 1, 3)
		
		mo.engineClass = allClasses[speedVar][weightVar]
	else
		if not mo.origSounds then
			mo.origSounds = {}
			for i = 0, 12 do
				mo.origSounds[i] = mo.engineClass+i
			end
		end
		for i = 0, 12 do
		   replaceSoundByMobj(mo, mo.origSounds[i], replSounds[i])
		end
	end
end, MT_PLAYER)
